@@ -11,8 +11,27 @@ require DynaLoader;
 
 our @ISA = qw( DynaLoader Search::Xapian::Weight);
 
+# In a new thread, copy objects of this class to unblessed, undef values.
+sub CLONE_SKIP { 1 }
+
+sub new {
+  my $class = shift;
+  my $weight;
+
+  if (scalar(@_) == 0) {
+    $weight = new1();
+  } else {
+    Carp::carp("USAGE: $class->new()");
+    exit;
+  }
+  bless $weight, $class;
+  return $weight;
+}
+
 1;
 
+__END__
+
 =head1 NAME
 
 Search::Xapian::BoolWeight - Boolean Weighting scheme.
@@ -23,7 +42,7 @@ Boolean Weighting scheme. All documents get a weight of 0.
 
 =head1 METHODS
 
-=over 4 
+=over 4
 
 =item new
 
@@ -36,4 +55,3 @@ Constructor. Takes no arguments.
 L<Search::Xapian>,L<Search::Xapian::Enquire>
 
 =cut
-
